@@ -1,7 +1,5 @@
+#' @useDynLib statgenQTLxT, .registration = TRUE
+#' @importFrom Rcpp sourceCpp
 #' @keywords internal
 "_PACKAGE"
 
-#' @docType package
-#' @useDynLib statgenQTLxT, .registration = TRUE
-#' @importFrom Rcpp sourceCpp
-NULL
